function imagearray = imageconvert(varargin);

%Function imageconvert
%Purpose - Converts crystal image into 1024x1024 gray scale array
%
%Inputs -   
%           filename - Name of crystal image file (or complete path) 
%           (e.g. 'i_0_01.jpg' or '0\i_0_01.jpg' (need single quotations))
%           dirname  - Name of crystal directory
%           (e.g. '0' or '5' (defaults to .))
%
%Outputs - imagearray - 1024x1024 grayscale array containing image info
%
%Example Use: im = imageconvert('0','i_0_01.jpg');
%OR           im = imageconvert('0\i_0_01.jpg');

if size(varargin,2) == 2
    realfilename = [varargin{1},'\',varargin{2}];
elseif size(varargin,1) == 1
    realfilename = varargin{1};
else
    'Error in imageconvert : Need to pass filename as arguments'
    exit;
end

%Read in file
im = imread(realfilename);
%Change to grayscale
imgray = RGB2Gray(im);
%Crop dimensions
imagearray = (imgray(1:1024,128:1024+127));




